@@ -34,6 +34,7 @@ class Message(IntEnum):
     PROTOCOL = 16
     INPUT = 17
     VERSION = 18
+    METRIC = 19
 
 ResultMessages = [
     Message.OK,
@@ -52,5 +53,5 @@ MessageMap = namedtuple(
         "NONE TEST NULL OK FAIL SKIP ERROR "
         "EXCEPTION VALUE NOTE DEBUG TRACE "
         "XOK XFAIL XERROR XNULL PROTOCOL INPUT "
-        "VERSION"
+        "VERSION METRIC"
     )
\ No newline at end of file
